Index: wp-includes/post.php
===================================================================
--- wp-includes/post.php	(revision 18116)
+++ wp-includes/post.php	(working copy)
@@ -55,6 +55,7 @@
 		'rewrite' => false,
 		'query_var' => false,
 		'show_in_nav_menus' => false,
+		'supports' => array( 'comments' ),
 	) );
 
 	register_post_type( 'revision', array(

Index: wp-content/themes/twentyeleven/comments.php
===================================================================
--- wp-content/themes/twentyeleven/comments.php	(revision 18116)
+++ wp-content/themes/twentyeleven/comments.php	(working copy)
@@ -63,24 +63,13 @@
 		</nav>
 		<?php endif; // check for comment navigation ?>
 
-	<?php else : // this is displayed if there are no comments so far ?>
-
-		<?php if ( comments_open() ) : // If comments are open, but there are no comments ?>
-
-		<?php else : // or, if we don't have comments:
-
-			/* If there are no comments and comments are closed,
-			 * let's leave a little note, shall we?
-			 * But only on posts! We don't want the note on pages.
-			 */
-			if ( ! comments_open() && ! is_page() ) :
-			?>
-			<p class="nocomments"><?php _e( 'Comments are closed.', 'twentyeleven' ); ?></p>
-			<?php endif; // end ! comments_open() && ! is_page() ?>
-
-
-		<?php endif; ?>
-
+	<?php 
+		/* If there are no comments and comments are closed, let's leave a little note, shall we?
+		 * But we don't want the note on pages or post types that do not support comments.
+		 */
+		elseif ( ! comments_open() && ! is_page() && post_type_supports( get_post_type(), 'comments' ) ) :
+	?>
+		<p class="nocomments"><?php _e( 'Comments are closed.', 'twentyeleven' ); ?></p>
 	<?php endif; ?>
 
 	<?php comment_form(); ?>